#
# spec file for package lua-penlight
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Togan Muftuoglu toganm@opensuse.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua53%{nil}
%define mod_name penlight
%define rname Penlight
%ifluadefault
%define with_main 1
%endif
Version:        1.14.0
Release:        1.1
Summary:        Generally useful modules inspired by the Python standard libraries
License:        MIT
Group:          Development/Languages/Other
URL:            https://lunarmodules.github.io/Penlight/
Source0:        https://github.com/lunarmodules/Penlight/archive/%{version}/%{rname}-%{version}.tar.gz
BuildRequires:  %{flavor}-devel
BuildRequires:  %{flavor}-ldoc
BuildRequires:  %{flavor}-luafilesystem
BuildRequires:  %{flavor}-markdown
BuildRequires:  lua-macros
Requires:       %{flavor}
Requires:       %{flavor}-luafilesystem
Recommends:     lua-%{mod_name}-doc
BuildArch:      noarch
%lua_provides
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif

%description
A set of pure Lua libraries focusing on input data handling (such as
reading configuration files), functional programming (such as map,
reduce, placeholder expressions,etc), and OS path management. Much of
the functionality is inspired by the Python standard libraries.

%if 0%{?with_main}
%package -n lua-%{mod_name}-doc
Summary:        Documentation for lua-%{mod_name}
Group:          Development/Languages/Other

%description -n lua-%{mod_name}-doc
Documentation for the package lua-%{mod_name}
%endif

%prep
%autosetup -n %{rname}-%{version} -p1

%build

%install
mkdir -p %{buildroot}%{lua_noarchdir}
cp -av lua/pl %{buildroot}%{lua_noarchdir}

# fix scripts
chmod -x %{buildroot}%{lua_noarchdir}/pl/dir.lua

# build and install README etc.
lua%{lua_version} %{lua_noarchdir}/markdown.lua *.md

%check
LUA_PATH="%{buildroot}%{lua_noarchdir}/?/init.lua;%{buildroot}%{lua_noarchdir}/?.lua;;" \
lua%{lua_version} run.lua tests

%files
%license LICENSE.md
%doc README.md *.html
%{lua_noarchdir}/pl
# Add bash/zsh-completion files
# from completions/bash/penlight.bash penlight

%if 0%{?with_main}
%files -n lua-%{mod_name}-doc
%doc docs
%endif

%changelog
* Thu Jun 13 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to version 0.14.0:
  * fix(path): make `path.expanduser` more sturdy
  * feat(func): extend `compose` to support N functions
  * fix(utils) `nil` values in `utils.choose(cond, val1, val2)`
  * fix(template) using `%%` as an escape character caused the
    expression to not be recognized
  * enhance(template): Preserve line numbers
* Wed Nov 23 2022 Michal Suchanek <msuchanek@suse.com>
- Fix missing dependency on lua-macros (boo#1205612)
* Sat Aug 20 2022 Gordon Leung <pirateclip@protonmail.com>
- Update to version 1.13.1:
  * fix tests on Lua 5.4.3
  * fix(stringx) strip using wrong index if # > 200
  * fix(path) currentdir does not accept parameters
  * etc. https://github.com/lunarmodules/Penlight/compare/1.10.0...1.13.1
- Removed lua5_4_3.patch: upstream
* Wed Apr 21 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.10.0:
  * Fix Lua 5.4 issues
  * Fix Lua 5.1 compat issues
  * Fixed a lot of bugs
- Removed lua54.patch: upstream
- Added lua5_4_3.patch: fix tests fail on Lua 5.4.3
* Thu Feb 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro for default lua versioning
* Tue Jul  7 2020 Matej Cepl <mcepl@suse.com>
- Add lua54.patch adding compatiblity with Lua 5.4
  (gh#Tieske/Penlight#320)
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target
* Fri Nov 30 2018 mcepl@suse.com
- Initial packaging
